==> lismadmin-1.0.1.tgz: lismadmin-1.0.1/lismadmin/www/js/read.js <==
//
function doRefer(action, dn) {
    //
    var form = document.input;
    if (form == null) {
        return;
    }
    //
    form.operation.value = "read";
    form.dn.value = dn;
    //
    form.elements[action].value = "true";
    //
    form.submit();
}
//
function doChangePage(frame, action, page) {
    //
    top.frames[frame].doSearch(action, page, 0);
}
//
function doDelete(action, dn, name) {
    //
    var form = document.input;
    if (form == null) {
        return;
    }
    //
    if (!confirm(
        name + "を削除します。\n"
        + "よろしいですか？")) {
        return;
    }
    //
    form.operation.value = "read";
    if (dn != null) {
        form.dn.value = dn;
    }
    //
    form.elements[action].value = "true";
    //
    form.submit();
}
//
function doDownloadFile(frame, action) {
    //
    top.frames[frame].doSearch(action, 1, 1);
}

//チェックボックスの全て選択 added by okazaki 20090316
//@param prefix この文字+"_"をidの先頭に含むチェックボックスを全て選択
function checkOn(prefix){
    var regexp = new RegExp("^" + prefix + "_");
    var inputs = document.getElementsByTagName("input");

    for(var i=0; i<inputs.length; i++){
        var input = inputs[i];
        if(input.type == "checkbox" && input.id.match(regexp))
            input.checked = true;
    }
}

//チェックボックスの全て解除 added by okazaki 20090316
//@param prefix この文字+"_"をidの先頭に含むチェックボックスを全て解除
function checkOff(prefix){
    var regexp = new RegExp("^" + prefix + "_");
    var inputs = document.getElementsByTagName("input");

    for(var i=0; i<inputs.length; i++){
        var input = inputs[i];
        if(input.type == "checkbox" && input.id.match(regexp))
            input.checked = false;
    }
}

//ラジオボタンのチェックの有無で入力可能か制御 added by okazaki 20090316
//ラジオボタンのvalue+"_"を先頭に含むテキストボックスのdisabledを解除
//それ以外のテキストボックスをdisabledに設定
function radioFunc(r){
    var target = new RegExp("^(user|group)_[^_]+$");
    var regexp = new RegExp("^" + r.value + "_");
    var form = document.input

    if (form == null) {
        return;
    }

    for(var i=0; i < form.elements.length; i++){
        var input = form.elements[i];

        if (input.name.match(target)) {
            if(input.name.match(regexp))
                input.disabled = !r.checked;
            else input.disabled = r.checked;
        }
    }
}

//ページが読み込まれたさいにラジオボタンがチェックされているテキストボックスのみ使用可能にする
function textOn(){
    var inputs = document.getElementsByTagName("input");
    for(var i=0; i<inputs.length; i++){
        if(inputs[i].type == "radio" && inputs[i].checked){
            radioFunc(inputs[i]);
        }
    }
}

==> lismadmin-2.0.0.tgz: lismadmin-2.0.0/lismadmin/www/js/read.js <==
//
function doRefer(action, dn) {
    //
    var form = document.input;
    if (form == null) {
        return;
    }
    //
    form.operation.value = "read";
    form.dn.value = dn;
    //
    form.elements[action].value = "true";
    //
    form.submit();
}
//
function doChangePage(frame, action, page) {
    //
    top.frames[frame].doSearch(action, page, 0);
}
//
function doDelete(action, dn, name) {
    //
    var form = document.input;
    if (form == null) {
        return;
    }
    //
    if (!confirm(
        name + "を削除します。\n"
        + "よろしいですか？")) {
        return;
    }
    //
    form.operation.value = "read";
    if (dn != null) {
        form.dn.value = dn;
    }
    //
    form.elements[action].value = "true";
    //
    form.submit();
}
//
function doDownloadFile(frame, action) {
    //
    top.frames[frame].doSearch(action, 1, 1);
}

//チェックボックスの全て選択 added by okazaki 20090316
//@param prefix この文字+"_"をidの先頭に含むチェックボックスを全て選択
function checkOn(prefix){
    var regexp = new RegExp("^" + prefix + "_");
    var inputs = document.getElementsByTagName("input");

    for(var i=0; i<inputs.length; i++){
        var input = inputs[i];
        if(input.type == "checkbox" && input.id.match(regexp))
            input.checked = true;
    }
}

//チェックボックスの全て解除 added by okazaki 20090316
//@param prefix この文字+"_"をidの先頭に含むチェックボックスを全て解除
function checkOff(prefix){
    var regexp = new RegExp("^" + prefix + "_");
    var inputs = document.getElementsByTagName("input");

    for(var i=0; i<inputs.length; i++){
        var input = inputs[i];
        if(input.type == "checkbox" && input.id.match(regexp))
            input.checked = false;
    }
}

//ラジオボタンのチェックの有無で入力可能か制御 added by okazaki 20090316
//ラジオボタンのvalue+"_"を先頭に含むテキストボックスのdisabledを解除
//それ以外のテキストボックスをdisabledに設定
function radioFunc(r){
    var target = new RegExp("^(user|group|every|once)_[^_]+$");
    var regexp = new RegExp("^" + r.value + "_");
    var form = document.input

    if (form == null) {
        return;
    }

    for(var i=0; i < form.elements.length; i++){
        var input = form.elements[i];

        if (input.name.match(target)) {
            if(input.name.match(regexp))
                input.disabled = !r.checked;
            else input.disabled = r.checked;
        }
    }
}

//ページが読み込まれたさいにラジオボタンがチェックされているテキストボックスのみ使用可能にする
function textOn(){
    var inputs = document.getElementsByTagName("input");
    for(var i=0; i<inputs.length; i++){
        if(inputs[i].type == "radio" && inputs[i].checked){
            radioFunc(inputs[i]);
        }
    }
}
